@@ -1,7 +1,8 @@
 from numalogic.models.autoencoder.variants.vanilla import VanillaAE
 from numalogic.models.autoencoder.variants.conv import Conv1dAE
 from numalogic.models.autoencoder.variants.lstm import LSTMAE
+from numalogic.models.autoencoder.variants.transformer import TransformerAE
 from numalogic.models.autoencoder.base import TorchAE
 
 
-__all__ = ["VanillaAE", "Conv1dAE", "LSTMAE", "TorchAE"]
+__all__ = ["VanillaAE", "Conv1dAE", "LSTMAE", "TransformerAE", "TorchAE"]
